summaryrefslogtreecommitdiff
path: root/protocols/Facebook/src/proto.h
diff options
context:
space:
mode:
authorGeorge Hazan <ghazan@miranda.im>2020-05-15 19:53:39 +0300
committerGeorge Hazan <ghazan@miranda.im>2020-05-15 19:53:39 +0300
commitd2dab81d17eafa10fb55b675090f6110ff7f7930 (patch)
tree9622499649ccb0ddc98e88260342e41e7289343d /protocols/Facebook/src/proto.h
parentefbd3e90b66f16d3aac1d99f15ce7f2f83477b4e (diff)
fixes #1012 (Facebook: option needed to load friends only)
Diffstat (limited to 'protocols/Facebook/src/proto.h')
-rw-r--r--protocols/Facebook/src/proto.h13
1 files changed, 7 insertions, 6 deletions
diff --git a/protocols/Facebook/src/proto.h b/protocols/Facebook/src/proto.h
index 1df80c6e4d..6ae38f2ca1 100644
--- a/protocols/Facebook/src/proto.h
+++ b/protocols/Facebook/src/proto.h
@@ -498,12 +498,13 @@ public:
//////////////////////////////////////////////////////////////////////////////////////
// options
- CMOption<wchar_t *> m_wszDefaultGroup; // clist group to store contacts
- CMOption<bool> m_bUseBigAvatars; // use big or small avatars by default
- CMOption<bool> m_bUseGroupchats; // do we need group chats at all?
- CMOption<bool> m_bHideGroupchats; // do not open chat windows on creation
- CMOption<bool> m_bLoginInvisible; // login in the invisible mode
- CMOption<bool> m_bKeepUnread; // do not mark incoming messages as read
+ CMOption<wchar_t *> m_wszDefaultGroup; // clist group to store contacts
+ CMOption<bool> m_bUseBigAvatars; // use big or small avatars by default
+ CMOption<bool> m_bUseGroupchats; // do we need group chats at all?
+ CMOption<bool> m_bHideGroupchats; // do not open chat windows on creation
+ CMOption<bool> m_bLoginInvisible; // login in the invisible mode
+ CMOption<bool> m_bKeepUnread; // do not mark incoming messages as read
+ CMOption<bool> m_bLoadAll; // load all contacts, not only those who have ARE_FRIENDS status
////////////////////////////////////////////////////////////////////////////////////////
// PROTO_INTERFACE